@@ -1,6 +1,6 @@
 #!/usr/bin/env python 
 '''
-Copyright (C) 2005 Aaron Spike, aaron@ekips.org
+Copyright (C) 2005,2007 Aaron Spike, aaron@ekips.org
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,9 +17,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 '''
 
-import inkex, os, base64
+import inkex, os, base64, urlparse, urllib
+import gettext
+_ = gettext.gettext
 
-class MyEffect(inkex.Effect):
+class Embedder(inkex.Effect):
     def __init__(self):
         inkex.Effect.__init__(self)
         self.OptionParser.add_option("-s", "--selectedonly",
@@ -28,46 +30,55 @@ class MyEffect(inkex.Effect):
             help="embed only selected images")
 
     def effect(self):
-        ctx = inkex.xml.xpath.Context.Context(self.document,processorNss=inkex.NSS)
-
         # if slectedonly is enabled and there is a selection only embed selected
         # images. otherwise embed all images
         if (self.options.selectedonly):
-            if (self.options.ids):
-                for id, node in self.selected.iteritems():
-                    if node.tagName == 'image':
-                        self.embedImage(node)
+            self.embedSelected(self.document, self.selected)
         else:
-            path = '//image'
-            for node in inkex.xml.xpath.Evaluate(path,self.document, context=ctx):
-                self.embedImage(node)
-    def embedImage(self, node):
-        xlink = node.attributes.getNamedItemNS(inkex.NSS[u'xlink'],'href')
-        if (xlink.value[:4]!='data'):
-            absref=node.attributes.getNamedItemNS(inkex.NSS[u'sodipodi'],'absref')
-            href=node.attributes.getNamedItemNS(inkex.NSS[u'xlink'],'href')
-            svg=self.document.getElementsByTagName('svg')[0]
-            docbase=svg.attributes.getNamedItemNS(inkex.NSS[u'sodipodi'],'docbase')
+            self.embedAll(self.document)
 
+    def embedSelected(self, document, selected):
+        self.document=document
+        self.selected=selected
+        if (self.options.ids):
+            for id, node in selected.iteritems():
+                if node.tag == inkex.addNS('image','svg'):
+                    self.embedImage(node)
+
+    def embedAll(self, document):
+        self.document=document #not that nice... oh well
+        path = '//svg:image'
+        for node in self.document.getroot().xpath(path, namespaces=inkex.NSS):
+            self.embedImage(node)
+
+    def embedImage(self, node):
+        xlink = node.get(inkex.addNS('href','xlink'))
+        if xlink is None or xlink[:5] != 'data:':
+            absref=node.get(inkex.addNS('absref','sodipodi'))
+            url=urlparse.urlparse(xlink)
+            href=urllib.url2pathname(url.path)
+            
             path=''
             #path selection strategy:
             # 1. href if absolute
-            # 2. sodipodi:docbase + href
-            # 3. realpath-ified href
-            # 4. absref, only if the above does not point to a file
+            # 2. realpath-ified href
+            # 3. absref, only if the above does not point to a file
             if (href != None):
-                if (os.path.isabs(href.value)):
-                    path=os.path.realpath(href.value)
-                elif (docbase != None):
-                    path=os.path.join(docbase.value,href.value)
-                else:
-                    path=os.path.realpath(href.value)
+                path=os.path.realpath(href)
             if (not os.path.isfile(path)):
                 if (absref != None):
-                    path=absref.value
+                    path=absref
+
+            try:
+                path=unicode(path, "utf-8")
+            except TypeError:
+                path=path
+
             if (not os.path.isfile(path)):
-                inkex.debug('No xlink:href or sodipodi:absref attributes found, or they do not point to an existing file! Unable to embed image.')
-            
+                inkex.errormsg(_('No xlink:href or sodipodi:absref attributes found, or they do not point to an existing file! Unable to embed image.'))
+                if path:
+                    inkex.errormsg(_("Sorry we could not locate %s") % path)
+
             if (os.path.isfile(path)):
                 file = open(path,"rb").read()
                 embed=True
@@ -79,17 +90,23 @@ class MyEffect(inkex.Effect):
                     type='image/bmp'
                 elif (file[:6]=='GIF87a' or file[:6]=='GIF89a'):
                     type='image/gif'
+                elif (file[:4]=='MM\x00\x2a' or file[:4]=='II\x2a\x00'):
+                    type='image/tiff'
                 #ico files lack any magic... therefore we check the filename instead
                 elif(path.endswith('.ico')):
                     type='image/x-icon' #official IANA registered MIME is 'image/vnd.microsoft.icon' tho
                 else:
                     embed=False
                 if (embed):
-                    xlink.value = 'data:%s;base64,%s' % (type, base64.encodestring(file))
-                    node.removeAttributeNS(inkex.NSS[u'sodipodi'],'absref')
+                    node.set(inkex.addNS('href','xlink'), 'data:%s;base64,%s' % (type, base64.encodestring(file)))
+                    if (absref != None):
+                        del node.attrib[inkex.addNS('absref',u'sodipodi')]
                 else:
-                    inkex.debug("%s is not of type image/png, image/jpeg, image/bmp, image/gif or image/x-icon" % path)
-            else:
-                inkex.debug("Sorry we could not locate %s" % path)
-e = MyEffect()
-e.affect()
+                    inkex.errormsg(_("%s is not of type image/png, image/jpeg, image/bmp, image/gif, image/tiff, or image/x-icon") % path)
+
+if __name__ == '__main__':
+    e = Embedder()
+    e.affect()
+
+
+# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 encoding=utf-8 textwidth=99
