@@ -5,12 +5,12 @@
 #define noDEBUG_LCMS
 
 #include <glib/gstdio.h>
-#include <sys/fcntl.h>
+#include <fcntl.h>
 #include <gdkmm/color.h>
 #include <glib/gi18n.h>
 
 #ifdef DEBUG_LCMS
-#include <gtk.h>
+#include <gtk/gtk.h>
 #endif // DEBUG_LCMS
 
 #include <cstring>
@@ -103,6 +103,8 @@ extern guint update_in_progress;
 
 static SPObjectClass *cprof_parent_class;
 
+namespace Inkscape {
+
 class ColorProfileImpl {
 public:
 #if defined(HAVE_LIBLCMS1) || defined(HAVE_LIBLCMS2)
@@ -129,10 +131,6 @@ public:
 #endif // defined(HAVE_LIBLCMS1) || defined(HAVE_LIBLCMS2)
 };
 
-
-
-namespace Inkscape {
-
 #if defined(HAVE_LIBLCMS1) || defined(HAVE_LIBLCMS2)
 cmsColorSpaceSignature asICColorSpaceSig(ColorSpaceSig const & sig)
 {
@@ -641,9 +639,9 @@ bool ColorProfile::GamutCheck(SPColor color)
 
     cmsUInt8Number outofgamut = 0;
     guchar check_color[4] = {
-        SP_RGBA32_R_U(val),
-        SP_RGBA32_G_U(val),
-        SP_RGBA32_B_U(val),
+        static_cast<guchar>(SP_RGBA32_R_U(val)),
+        static_cast<guchar>(SP_RGBA32_G_U(val)),
+        static_cast<guchar>(SP_RGBA32_B_U(val)),
         255};
     cmsDoTransform(ColorProfile::getTransfGamutCheck(), &check_color, &outofgamut, 1);
 
@@ -821,7 +819,7 @@ std::vector<Glib::ustring> ColorProfile::getBaseProfileDirs() {
 #ifdef WIN32
     wchar_t pathBuf[MAX_PATH + 1];
     pathBuf[0] = 0;
-    cmsUInt32Number pathSize = sizeof(pathBuf);
+    DWORD pathSize = sizeof(pathBuf);
     g_assert(sizeof(wchar_t) == sizeof(gunichar2));
     if ( GetColorDirectoryW( NULL, pathBuf, &pathSize ) ) {
         gchar * utf8Path = g_utf16_to_utf8( (gunichar2*)(&pathBuf[0]), -1, NULL, NULL, NULL );
@@ -982,7 +980,7 @@ Glib::ustring getNameFromProfile(cmsHPROFILE profile)
         }
         nameStr = Glib::ustring(data.begin(), data.end());
     }
-    if (nameStr.empty()) {
+    if (nameStr.empty() || !g_utf8_validate(nameStr.c_str(), -1, NULL)) {
         nameStr = _("(invalid UTF-8 string)");
     }
 #endif
