@@ -726,17 +726,19 @@ void Script::effect(Inkscape::Extension::Effect *module,
         copy_doc(doc->doc()->rroot, mydoc->rroot);
         doc->doc()->emitReconstructionFinish();
         SPObject *layer = NULL;
-        SPObject *obj = mydoc->getObjectById("base");
+
         // Getting the named view from the document generated by the extension
-        SPNamedView *nv = (SPNamedView *) obj;
-        
+        SPNamedView *nv = sp_document_namedview(mydoc, NULL);
+
         //Check if it has a default layer set up
-        if ( nv->default_layer_id != 0 ) {
-            SPDocument *document = desktop->doc();
-            //If so, get that layer
-            layer = document->getObjectById(g_quark_to_string(nv->default_layer_id));
+        if ( nv != NULL){
+            if( nv->default_layer_id != 0 ) {
+                SPDocument *document = desktop->doc();
+                //If so, get that layer
+                layer = document->getObjectById(g_quark_to_string(nv->default_layer_id));
+            }
         }
-        
+
         sp_namedview_update_layers_from_document(desktop);
         //If that layer exists,
         if (layer) {
