@@ -273,7 +273,7 @@ public:
 
     void save  (Inkscape::Extension::Output *mod,
 	        SPDocument *doc,
-	        const gchar *uri);
+	        gchar const *filename);
 
     static void   init  (void);
 
@@ -316,7 +316,7 @@ private:
     bool processStyle(Writer &outs, SPItem *item, const Glib::ustring &id);
 
     bool processGradient(Writer &outs, SPItem *item,
-                    const Glib::ustring &id, NR::Matrix &tf);
+                    const Glib::ustring &id, Geom::Matrix &tf);
 
     bool writeStyleHeader(Writer &outs);
 
