@@ -19,7 +19,6 @@
 #ifdef HAVE_POPPLER
 
 #include "svg-builder.h"
-#include "pdf-parser.h"
 
 #include <png.h>
 
@@ -47,6 +46,8 @@
 #include "UnicodeMap.h"
 #include "GlobalParams.h"
 
+#include "pdf-parser.h"
+ 
 namespace Inkscape {
 namespace Extension {
 namespace Internal {
@@ -62,7 +63,7 @@ namespace Internal {
  * \brief Holds information about a PDF transparency group
  */
 struct SvgTransparencyGroup {
-    double bbox[6];
+    double bbox[4];
     Inkscape::XML::Node *container;
 
     bool isolated;
@@ -289,14 +290,6 @@ static gchar *svgInterpretPath(GfxPath *path) {
  * Uses the given SPCSSAttr for storing the style properties
  */
 void SvgBuilder::_setStrokeStyle(SPCSSAttr *css, GfxState *state) {
-
-    // Check line width
-    if ( state->getLineWidth() <= 0.0 ) {
-        // Ignore stroke
-        sp_repr_css_set_property(css, "stroke", "none");
-        return;
-    }
-
     // Stroke color/pattern
     if ( state->getStrokeColorSpace()->getMode() == csPattern ) {
         gchar *urltext = _createPattern(state->getStrokePattern(), state, true);
@@ -317,7 +310,14 @@ void SvgBuilder::_setStrokeStyle(SPCSSAttr *css, GfxState *state) {
 
     // Line width
     Inkscape::CSSOStringStream os_width;
-    os_width << state->getLineWidth();
+    double lw = state->getLineWidth();
+    if (lw > 0.0) {
+        os_width << lw;
+    } else {
+        // emit a stroke which is 1px in toplevel user units
+        double pxw = PT_PER_PX;
+        os_width << 1.0 / state->transformWidth(pxw);
+    }
     sp_repr_css_set_property(css, "stroke-width", os_width.str().c_str());
 
     // Line cap
@@ -903,7 +903,7 @@ std::string SvgBuilder::_BestMatchingFont(std::string PDFname)
         std::string fontname = _availableFontNames[i];
         
         // At least the first word of the font name should match.
-        guint minMatch = fontname.find(" ");
+        std::size_t minMatch = fontname.find(" ");
         if (minMatch == std::string::npos) {
            minMatch = fontname.length();
         }
@@ -1774,7 +1774,7 @@ void SvgBuilder::pushTransparencyGroup(GfxState *state, double *bbox,
 
     // Setup new transparency group
     SvgTransparencyGroup *transpGroup = new SvgTransparencyGroup;
-    memcpy(&transpGroup->bbox, bbox, sizeof(bbox));
+    memcpy(&transpGroup->bbox, bbox, 4 * sizeof(double));
     transpGroup->isolated = isolated;
     transpGroup->knockout = knockout;
     transpGroup->for_softmask = for_softmask;
