@@ -1172,7 +1172,7 @@ GrDragger::updateTip ()
         }
         g_free(item_desc);
     } else if (g_slist_length (draggables) == 2 && isA (POINT_RG_CENTER) && isA (POINT_RG_FOCUS)) {
-        this->knot->tip = g_strdup_printf (_("Radial gradient <b>center</b> and <b>focus</b>; drag with <b>Shift</b> to separate focus"));
+        this->knot->tip = g_strdup_printf ("%s", _("Radial gradient <b>center</b> and <b>focus</b>; drag with <b>Shift</b> to separate focus"));
     } else {
         int length = g_slist_length (this->draggables);
         this->knot->tip = g_strdup_printf (ngettext("Gradient point shared by <b>%d</b> gradient; drag with <b>Shift</b> to separate",
@@ -1969,7 +1969,7 @@ GrDrag::deleteSelected (bool just_one)
 {
     if (!selected) return;
 
-    SPDocument *document = false;
+    SPDocument *document = NULL;
 
     struct StructStopInfo {
         SPStop * spstop;
