@@ -1154,7 +1154,7 @@ sp_ui_drag_data_received(GtkWidget *widget,
                             sp_object_setAttribute( SP_OBJECT(item),
                                                     fillnotstroke ? "inkscape:x-fill-tag":"inkscape:x-stroke-tag",
                                                     palName.c_str(),
-                                                    false );
+                                                    NULL );
                             item->updateRepr();
 
                             sp_repr_css_set_property( css, fillnotstroke ? "fill":"stroke", c );
@@ -1577,14 +1577,16 @@ sp_ui_menu_item_set_name(SPAction */*action*/, Glib::ustring name, void *data)
     //- a GtkHBox, whose first child is a label displaying name if the menu
     //item has an accel key
     //- a GtkLabel if the menu has no accel key
-    if (GTK_IS_LABEL(child)) {
-        gtk_label_set_markup_with_mnemonic(GTK_LABEL (child), name.c_str());
-    } else if (GTK_IS_HBOX(child)) {
-        gtk_label_set_markup_with_mnemonic(
-        GTK_LABEL (gtk_container_get_children(GTK_CONTAINER (child))->data),
-        name.c_str());
-    }//else sp_ui_menu_append_item_from_verb has been modified and can set
-    //a menu item in yet another way...
+    if (child != NULL){
+        if (GTK_IS_LABEL(child)) {
+            gtk_label_set_markup_with_mnemonic(GTK_LABEL (child), name.c_str());
+        } else if (GTK_IS_HBOX(child)) {
+            gtk_label_set_markup_with_mnemonic(
+            GTK_LABEL (gtk_container_get_children(GTK_CONTAINER (child))->data),
+            name.c_str());
+        }//else sp_ui_menu_append_item_from_verb has been modified and can set
+        //a menu item in yet another way...
+    }
 }
 
 void injectRenamedIcons()
