@@ -104,7 +104,7 @@ static FILE *fopen_utf8name( char const *utf8name, int mode )
  *
  */
 UriInputStream::UriInputStream(Inkscape::URI &source)
-                    throw (StreamException): uri(source)
+   : uri(source)
 {
     //get information from uri
     char const *schemestr = uri.getScheme();
@@ -146,8 +146,8 @@ UriInputStream::UriInputStream(Inkscape::URI &source)
  *
  */
 UriInputStream::UriInputStream(FILE *source, Inkscape::URI &uri)
-    throw (StreamException): inf(source),
-                             uri(uri)
+    : inf(source),
+      uri(uri)
 {
     scheme = SCHEME_FILE;
     if (!inf) {
@@ -160,7 +160,7 @@ UriInputStream::UriInputStream(FILE *source, Inkscape::URI &uri)
 /**
  *
  */
-UriInputStream::~UriInputStream() throw(StreamException)
+UriInputStream::~UriInputStream()
 {
     close();
 }
@@ -170,7 +170,7 @@ UriInputStream::~UriInputStream() throw(StreamException)
  * this input stream without blocking by the next caller of a method for
  * this input stream.
  */
-int UriInputStream::available() throw(StreamException)
+int UriInputStream::available()
 {
     return 0;
 }
@@ -180,7 +180,7 @@ int UriInputStream::available() throw(StreamException)
  *  Closes this input stream and releases any system resources
  *  associated with the stream.
  */
-void UriInputStream::close() throw(StreamException)
+void UriInputStream::close()
 {
     if (closed)
         return;
@@ -207,7 +207,7 @@ void UriInputStream::close() throw(StreamException)
 /**
  * Reads the next byte of data from the input stream.  -1 if EOF
  */
-int UriInputStream::get() throw(StreamException)
+int UriInputStream::get()
 {
     int retVal = -1;
     if (!closed)
@@ -249,7 +249,6 @@ int UriInputStream::get() throw(StreamException)
  *
  */
 UriReader::UriReader(Inkscape::URI &uri)
-                    throw (StreamException)
 {
     inputStream = new UriInputStream(uri);
 }
@@ -257,7 +256,7 @@ UriReader::UriReader(Inkscape::URI &uri)
 /**
  *
  */
-UriReader::~UriReader() throw (StreamException)
+UriReader::~UriReader()
 {
     delete inputStream;
 }
@@ -265,7 +264,7 @@ UriReader::~UriReader() throw (StreamException)
 /**
  *
  */
-int UriReader::available() throw(StreamException)
+int UriReader::available()
 {
     return inputStream->available();
 }
@@ -273,7 +272,7 @@ int UriReader::available() throw(StreamException)
 /**
  *
  */
-void UriReader::close() throw(StreamException)
+void UriReader::close()
 {
     inputStream->close();
 }
@@ -281,7 +280,7 @@ void UriReader::close() throw(StreamException)
 /**
  *
  */
-gunichar UriReader::get() throw(StreamException)
+gunichar UriReader::get()
 {
     gunichar ch = (gunichar)inputStream->get();
     return ch;
@@ -296,11 +295,11 @@ gunichar UriReader::get() throw(StreamException)
  * Temporary kludge
  */
 UriOutputStream::UriOutputStream(FILE* fp, Inkscape::URI &destination)
-                    throw (StreamException): closed(false),
-                                             ownsFile(false),
-                                             outf(fp),
-                                             uri(destination),
-                                             scheme(SCHEME_FILE)
+    : closed(false),
+      ownsFile(false),
+      outf(fp),
+      uri(destination),
+      scheme(SCHEME_FILE)
 {
     if (!outf) {
         Glib::ustring err = "UriOutputStream given null file ";
@@ -312,11 +311,11 @@ UriOutputStream::UriOutputStream(FILE* fp, Inkscape::URI &destination)
  *
  */
 UriOutputStream::UriOutputStream(Inkscape::URI &destination)
-                    throw (StreamException): closed(false),
-                                             ownsFile(true),
-                                             outf(NULL),
-                                             uri(destination),
-                                             scheme(SCHEME_FILE)
+    : closed(false),
+      ownsFile(true),
+      outf(NULL),
+      uri(destination),
+      scheme(SCHEME_FILE)
 {
     //get information from uri
     char const *schemestr = uri.getScheme();
@@ -353,7 +352,7 @@ UriOutputStream::UriOutputStream(Inkscape::URI &destination)
 /**
  *
  */
-UriOutputStream::~UriOutputStream() throw(StreamException)
+UriOutputStream::~UriOutputStream()
 {
     close();
 }
@@ -362,7 +361,7 @@ UriOutputStream::~UriOutputStream() throw(StreamException)
  * Closes this output stream and releases any system resources
  * associated with this stream.
  */
-void UriOutputStream::close() throw(StreamException)
+void UriOutputStream::close()
 {
     if (closed)
         return;
@@ -391,7 +390,7 @@ void UriOutputStream::close() throw(StreamException)
  *  Flushes this output stream and forces any buffered output
  *  bytes to be written out.
  */
-void UriOutputStream::flush() throw(StreamException)
+void UriOutputStream::flush()
 {
     if (closed)
         return;
@@ -415,7 +414,7 @@ void UriOutputStream::flush() throw(StreamException)
 /**
  * Writes the specified byte to this output stream.
  */
-void UriOutputStream::put(int ch) throw(StreamException)
+void UriOutputStream::put(int ch)
 {
     if (closed)
         return;
@@ -453,7 +452,6 @@ void UriOutputStream::put(int ch) throw(StreamException)
  *
  */
 UriWriter::UriWriter(Inkscape::URI &uri)
-                    throw (StreamException)
 {
     outputStream = new UriOutputStream(uri);
 }
@@ -461,7 +459,7 @@ UriWriter::UriWriter(Inkscape::URI &uri)
 /**
  *
  */
-UriWriter::~UriWriter() throw (StreamException)
+UriWriter::~UriWriter()
 {
     delete outputStream;
 }
@@ -469,7 +467,7 @@ UriWriter::~UriWriter() throw (StreamException)
 /**
  *
  */
-void UriWriter::close() throw(StreamException)
+void UriWriter::close()
 {
     outputStream->close();
 }
@@ -477,7 +475,7 @@ void UriWriter::close() throw(StreamException)
 /**
  *
  */
-void UriWriter::flush() throw(StreamException)
+void UriWriter::flush()
 {
     outputStream->flush();
 }
@@ -485,7 +483,7 @@ void UriWriter::flush() throw(StreamException)
 /**
  *
  */
-void UriWriter::put(gunichar ch) throw(StreamException)
+void UriWriter::put(gunichar ch)
 {
     int ich = (int)ch;
     outputStream->put(ich);
