@@ -16,8 +16,14 @@ class SPObject;
 
 namespace Inkscape {
 
-SPObject *create_layer(SPObject *root, SPObject *layer);
-
+enum LayerRelativePosition {
+    LPOS_ABOVE,
+    LPOS_BELOW,
+    LPOS_CHILD,
+};
+    
+SPObject *create_layer(SPObject *root, SPObject *layer, LayerRelativePosition position);
+    
 SPObject *next_layer(SPObject *root, SPObject *layer);
 
 SPObject *previous_layer(SPObject *root, SPObject *layer);
@@ -29,9 +35,9 @@ SPObject *previous_layer(SPObject *root, SPObject *layer);
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
