@@ -8,7 +8,7 @@
 
 #include <cstdio>
 #include <cstdlib>
-#include <glib/gmem.h>
+#include <glib.h>
 #include "Shape.h"
 #include "livarot/sweep-event-queue.h"
 #include "livarot/sweep-tree-list.h"
