@@ -281,10 +281,10 @@ sp_guide_create_guides_around_page(SPDesktop *dt) {
     Geom::Point B(C[Geom::X], 0);
     Geom::Point D(0, C[Geom::Y]);
 
-    pts.push_back(std::make_pair<Geom::Point, Geom::Point>(A, B));
-    pts.push_back(std::make_pair<Geom::Point, Geom::Point>(B, C));
-    pts.push_back(std::make_pair<Geom::Point, Geom::Point>(C, D));
-    pts.push_back(std::make_pair<Geom::Point, Geom::Point>(D, A));
+    pts.push_back(std::make_pair(A, B));
+    pts.push_back(std::make_pair(B, C));
+    pts.push_back(std::make_pair(C, D));
+    pts.push_back(std::make_pair(D, A));
 
     sp_guide_pt_pairs_to_guides(dt, pts);
 
