@@ -26,6 +26,7 @@ class SPImageClass;
 /* SPImage */
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glibmm/ustring.h>
 #include "svg/svg-length.h"
 #include "sp-item.h"
 #include "display/display-forward.h"
@@ -48,9 +49,9 @@ struct SPImage : public SPItem {
     SPCurve *curve; // This curve is at the image's boundary for snapping
 
     gchar *href;
-#if ENABLE_LCMS
+#if defined(HAVE_LIBLCMS1) || defined(HAVE_LIBLCMS2)
     gchar *color_profile;
-#endif // ENABLE_LCMS
+#endif // defined(HAVE_LIBLCMS1) || defined(HAVE_LIBLCMS2)
 
     GdkPixbuf *pixbuf;
     gchar *pixPath;
@@ -65,7 +66,7 @@ GType sp_image_get_type (void);
 
 /* Return duplicate of curve or NULL */
 SPCurve *sp_image_get_curve (SPImage *image);
-
+void sp_embed_image(Inkscape::XML::Node *imgnode, GdkPixbuf *pb, Glib::ustring const &mime);
 void sp_image_refresh_if_outdated( SPImage* image );
 
 #endif
