@@ -24,8 +24,8 @@ void sp_item_rm_unsatisfied_cns(SPItem &item)
         if (!approx_equal( sp_guide_distance_from_pt(cn.g, snappoints[snappoint_ix].getPoint()), 0) ) {
             remove_last(cn.g->attached_items, SPGuideAttachment(&item, cn.snappoint_ix));
             g_assert( i < item.constraints.size() );
-            vector<SPGuideConstraint>::iterator const ei(&item.constraints[i]);
-            item.constraints.erase(ei);
+            // vector<SPGuideConstraint>::iterator const ei(&item.constraints[i]);
+            // item.constraints.erase(ei);
         }
     }
 }
