@@ -205,6 +205,11 @@ sp_selected_path_boolop(SPDesktop *desktop, bool_op bop, const unsigned int verb
         curOrig = 0;
         for (GSList *l = il; l != NULL; l = l->next)
         {
+            // apply live path effects prior to performing boolean operation
+            if (SP_IS_LPE_ITEM(l->data)) {
+                sp_lpe_item_remove_all_path_effects(SP_LPE_ITEM(l->data), true);
+            }
+
             SPCSSAttr *css = sp_repr_css_attr(SP_OBJECT_REPR(il->data), "style");
             gchar const *val = sp_repr_css_property(css, "fill-rule", NULL);
             if (val && strcmp(val, "nonzero") == 0) {
@@ -1183,13 +1188,22 @@ sp_selected_path_outline(SPDesktop *desktop)
                                                              g_repr, xml_doc, doc );
                     }
                 }
+                //bug 1290573: completely destroy the old object first to prevent
+                //an ID clash, which has issues on undo
+                curve->unref();
+                selection->remove(item);
+                item->deleteObject(false);
 
                 selection->add(g_repr);
 
                 Inkscape::GC::release(g_repr);
 
-
             } else {
+                //bug 1290573: completely destroy the old object first to prevent
+                //an ID clash, which has issues on undo
+                curve->unref();
+                selection->remove(item);
+                item->deleteObject(false);
 
                 // add the new repr to the parent
                 parent->appendChild(repr);
@@ -1215,10 +1229,6 @@ sp_selected_path_outline(SPDesktop *desktop)
 
             Inkscape::GC::release(repr);
 
-            curve->unref();
-            selection->remove(item);
-            SP_OBJECT(item)->deleteObject(false);
-
         }
         if (title) g_free(title);
         if (desc) g_free(desc);
