@@ -2,7 +2,7 @@
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-/* $Id: /local/inkscape.rel.46/src/trace/potrace/greymap.h 16879 2007-10-26T21:01:30.934311Z ishmal  $ */
+/* $Id$ */
 
 #ifndef PGM_H
 #define PGM_H
@@ -45,7 +45,7 @@ typedef struct greymap_s greymap_t;
 #define GM_MODE_POSITIVE 3
 #define GM_MODE_NEGATIVE 4
 
-extern char *gm_read_error;
+extern char const *gm_read_error;
 
 greymap_t *gm_new(int w, int h);
 greymap_t *gm_dup(greymap_t *gm);
