@@ -5,17 +5,7 @@
  *
  *  Conversion to C++ for Inkscape by Bob Jamison
  *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
- *
- *  http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ *  Released under GNU GPL, read the file 'COPYING' for more information
  */
 
 /**
@@ -267,8 +257,8 @@ public:
      * If the coordinates are out of range, do nothing.
      */
     virtual void setPixel(unsigned int x, unsigned int y,
-                          unsigned int a, 
-                          unsigned int r, 
+                          unsigned int a,
+                          unsigned int r,
                           unsigned int g,
                           unsigned int b);
 
@@ -368,13 +358,13 @@ private:
      * Confidence matrix data
      */
     float *cmdata;
-    
+
 private:
 
     /**
      * Error logging
      */
-    void error(char *fmt, ...);
+    void error(const char *fmt, ...) G_GNUC_PRINTF(2,3);
 
 };
 
@@ -411,7 +401,7 @@ public:
      *  Informs the observer how much has been completed.
      *  Return false if the processing should be aborted.
      */
-    virtual bool progress(float percentCompleted)
+    virtual bool progress(float /*percentCompleted*/)
         {
         return true;
         }
@@ -420,7 +410,7 @@ public:
      *  Send an error string to the Observer.  Processing will
      *  be halted.
      */
-    virtual void error(const std::string &msg)
+    virtual void error(const std::string &/*msg*/)
         {
         }
 
@@ -453,7 +443,7 @@ public:
      */
     static const float FOREGROUND_CONFIDENCE; //=0.8f;
 
-    /** 
+    /**
      * Confidence for foreground or background type being equally likely.
      */
     static const float UNKNOWN_REGION_CONFIDENCE; //=0.5f;
@@ -562,12 +552,12 @@ private:
     /**
      * Error logging
      */
-    void error(char *fmt, ...);
+    void error(const char *fmt, ...) G_GNUC_PRINTF(2,3);
 
     /**
      * Trace logging
      */
-    void trace(char *fmt, ...);
+    void trace(const char *fmt, ...) G_GNUC_PRINTF(2,3);
 
     /**
      *  Stage 1 of the color signature work.  'dims' will be either
