@@ -231,7 +231,7 @@ Tracer::sioxProcessImage(SPImage *img,
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
     if (!desktop)
         {
-        g_warning(_("Trace: No active desktop"));
+        g_warning("%s", _("Trace: No active desktop"));
         return Glib::RefPtr<Gdk::Pixbuf>(NULL);
         }
 
@@ -331,7 +331,7 @@ Tracer::sioxProcessImage(SPImage *img,
     SioxImage result = sengine.extractForeground(simage, 0xffffff);
     if (!result.isValid())
         {
-        g_warning(_("Invalid SIOX result"));
+        g_warning("%s", _("Invalid SIOX result"));
         return Glib::RefPtr<Gdk::Pixbuf>(NULL);
         }
 
