@@ -154,7 +154,7 @@ PathManipulator::~PathManipulator()
 }
 
 /** Handle motion events to update the position of the curve drag point. */
-bool PathManipulator::event(GdkEvent *event)
+bool PathManipulator::event(SPEventContext *event_context, GdkEvent *event)
 {
     if (empty()) return false;
 
@@ -429,8 +429,8 @@ void PathManipulator::weldSegments()
                     sp->erase(sel_beg);
                     sel_beg = next;
                 }
-                sel_beg = sel_end;
             }
+            sel_beg = sel_end;
             num_selected -= num_points;
         }
     }
@@ -1211,6 +1211,10 @@ void PathManipulator::_getGeometry()
     } else {
         _spcurve->unref();
         _spcurve = sp_path_get_curve_for_edit(_path);
+        // never allow NULL spcurve!
+        if (_spcurve == NULL) {
+            _spcurve = new SPCurve();
+        }
     }
 }
 
