@@ -61,9 +61,6 @@ public:
 
     bool is_updating() {if (_wr) return _wr->isUpdating(); else return false;}
 
-    // provide automatic 'upcast' for ease of use. (do it 'dynamic_cast' instead of 'static' because who knows what W is)
-    operator const Gtk::Widget () { return dynamic_cast<Gtk::Widget*>(this); }
-
 protected:
     RegisteredWidget() : W() { construct(); }
     template< typename A >
