@@ -17,9 +17,10 @@
 
 #include <glib.h>
 
+#include <stddef.h>
 #include <sigc++/connection.h>
 
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 #include "../forward.h"
 
 #define SP_TYPE_GRADIENT_VECTOR_SELECTOR (sp_gradient_vector_selector_get_type ())
